@@ -92,9 +92,11 @@ class Conversions:
 
     def utc_from_datestring(self, datestring: str) -> dt.datetime:
         """Return a UTC time from a date string."""
-        date_obj = dt.datetime.strptime(f"{datestring} 00:00", "%Y-%m-%d %H:%M")
-        dt_obj = date_obj.replace(tzinfo=UTC)
-        return dt_obj.strftime("%Y-%m-%dT%H:%M:%S+00:00")
+        date_obj = dt.datetime.strptime(f"{datestring} 12:00", "%Y-%m-%d %H:%M")
+        return date_obj.astimezone(tz=UTC).isoformat()
+        # dt_obj = date_obj.replace(tzinfo=UTC)
+        # return dt_obj.isoformat()
+        # return dt_obj.strftime("%Y-%m-%dT%H:%M:%S+00:00")
 
     def utc_from_datetimestring(self, datestring: str) -> dt.datetime:
         """Return a UTC time from a datetime string."""
